@@ -1,4 +1,5 @@
-print.subjectWeights <- function(x,digits=3){
+#' @S3method print subjectWeights
+print.subjectWeights <- function(x,digits=3,...){
   cat("\nEstimated inverse of the probability of censoring weights (subjectWeights)\n\n")
   method=switch(x$method,
     "cox"="Cox regression",
